.. _admin:

Administration
==============

.. automodule:: geoalchemy2.admin
   :members:
   :private-members:
   :show-inheritance:


Common objects
--------------

.. automodule:: geoalchemy2.admin.dialects.common
   :members:
   :private-members:
   :show-inheritance:

PostgreSQL-specific objects
---------------------------

.. automodule:: geoalchemy2.admin.dialects.postgresql
   :members:
   :private-members:
   :show-inheritance:

MySQL-specific objects
---------------------------

.. automodule:: geoalchemy2.admin.dialects.mysql
   :members:
   :private-members:
   :show-inheritance:

SQLite-specific objects
---------------------------

.. automodule:: geoalchemy2.admin.dialects.sqlite
   :members:
   :private-members:
   :show-inheritance:

GeoPackage-specific objects
---------------------------

.. automodule:: geoalchemy2.admin.dialects.geopackage
   :members:
   :private-members:
   :show-inheritance:
